@@ -22,16 +22,12 @@
 #include <QObject>
 #include <QColor>
 
+class QModelIndex;
 namespace Analitza {
 	class Variables;
-	class Expression;
+	class PlotsModel;
 }
 
-class VariablesModel;
-class PluginsModel;
-class FunctionsModel;
-class AnalitzaWrapper;
-
 class KAlgebraMobile : public QObject
 {
 	Q_OBJECT
@@ -43,13 +39,13 @@ class KAlgebraMobile : public QObject
 		void notifyVariablesChanged() { variablesChanged(); }
 		
 	public slots:
-		FunctionsModel* functionsModel();
+		Analitza::PlotsModel* functionsModel();
 		Analitza::Variables* variables() const;
-		QStringList addFunction(const QString& expression, double up = 0., double down = 0.);
 		
 	private slots:
-		void functionRemoved(const QString& name);
-		void functionModified(const QString& name, const Analitza::Expression& exp);
+		void functionRemoved(const QModelIndex& parent, int start, int end);
+		void functionModified(const QModelIndex& idxA, const QModelIndex& idxB);
+        void functionInserted(const QModelIndex& parent, int start, int end);
 		
 	signals:
 		void variablesChanged();
@@ -57,7 +53,7 @@ class KAlgebraMobile : public QObject
 	private:
 		static KAlgebraMobile* s_self;
 		
-		FunctionsModel* m_functionsModel;
+		Analitza::PlotsModel* m_functionsModel;
 		Analitza::Variables* m_vars;
 };
 
