@@ -28,13 +28,16 @@
 #include <QListView>
 #include <config-kalgebra.h>
 
-class ExpressionEdit;
-class ConsoleHtml;
+namespace Analitza {
+class PlotsView2D;
+class PlotsView3D;
+class PlotsModel;
 class VariablesModel;
+class ExpressionEdit;
+}
+
+class ConsoleHtml;
 class FunctionEdit;
-class Graph2D;
-class Graph3D;
-class FunctionsModel;
 class KRecentFilesAction;
 
 namespace Analitza { class Expression; }
@@ -55,27 +58,28 @@ class KAlgebra : public KMainWindow
 		//consoleeWidget
 		QMenu* c_menu;
 		KRecentFilesAction* c_recentScripts;
-		ExpressionEdit *c_exp;
+		Analitza::ExpressionEdit *c_exp;
 		ConsoleHtml *c_results;
 		QTreeView *c_variables;
 		QDockWidget *c_dock_vars;
-		VariablesModel* c_varsModel;
+		Analitza::VariablesModel* c_varsModel;
 		
 		//graf 2d
 		QMenu* b_menu;
-		FunctionsModel* b_funcsModel;
+		Analitza::PlotsModel* b_funcsModel;
 		QTreeView *b_funcs;
 		QTabWidget *b_tools;
-		Graph2D *m_graph2d;
+		Analitza::PlotsView2D *m_graph2d;
 		QDockWidget *b_dock_funcs;
 		FunctionEdit *b_funced;
-		VariablesModel* b_varsModel;
+		Analitza::VariablesModel* b_varsModel;
 
 #ifdef HAVE_OPENGL
 		//graph 3d
 		QMenu* t_menu;
-		ExpressionEdit *t_exp;
-		Graph3D *m_graph3d;
+		Analitza::ExpressionEdit *t_exp;
+		Analitza::PlotsView3D *m_graph3d;
+        Analitza::PlotsModel* t_model3d;
 #endif
 		//Dictionary
 		QDockWidget *d_dock;
@@ -112,7 +116,6 @@ class KAlgebra : public KMainWindow
 		void set_dots();
 		void set_lines();
 		void set_solid();
-		void toggleTransparency();
 		void save3DGraph();
 		
 		void saveGraph();
